@@ -16,7 +16,7 @@ import os
 import inspect
 import sys
 
-from tropofy.app import LoadedApps, App, AppWithDataSets, AppDataSet, DataSetVar, SavedImageReference, FunctionExecutionInfo
+from tropofy.app import LoadedApps, App, AppWithDataSets, AppDataSet, DataSetVar, SavedImageReference, CeleryTask, SynchronousTask
 from tropofy.database.tropofy_orm import TropofyDbMetaData, DynamicSchemaName
 from sqlalchemy.engine import reflection
 from sqlalchemy.schema import CreateSchema
@@ -112,7 +112,8 @@ class AppManager(object):
                     TropofyDbMetaData.metadata.tables[DynamicSchemaName.get_schema_qualified_table_name_if_using_schemas(AppDataSet.__tablename__)],
                     TropofyDbMetaData.metadata.tables[DynamicSchemaName.get_schema_qualified_table_name_if_using_schemas(DataSetVar.__tablename__)],
                     TropofyDbMetaData.metadata.tables[DynamicSchemaName.get_schema_qualified_table_name_if_using_schemas(SavedImageReference.__tablename__)],
-                    TropofyDbMetaData.metadata.tables[DynamicSchemaName.get_schema_qualified_table_name_if_using_schemas(FunctionExecutionInfo.__tablename__)],
+                    TropofyDbMetaData.metadata.tables[DynamicSchemaName.get_schema_qualified_table_name_if_using_schemas(CeleryTask.__tablename__)],
+                    TropofyDbMetaData.metadata.tables[DynamicSchemaName.get_schema_qualified_table_name_if_using_schemas(SynchronousTask.__tablename__)],
                 ]
             )
 
