@@ -101,7 +101,7 @@ def refresh_widget_from_db(request):
         response = Response(widget_parameters['get_data'])
         response.content_type = 'text/plain'  # Must explicitly set for ie
         return response
-    elif request.widget.get_type() in ["FormWidget", "GridWidget", "SimpleGrid"]:  # Don't need to send up
+    elif request.widget.get_type() in ["FormWidget", "GridWidget", "SimpleGrid", "ExecuteFunctionWidget"]:  # Don't need to send up
         return widget_parameters
     else:
         data = {'widget_type': request.widget.get_type(), 'widget_parameters': widget_parameters}
